@@ -22,13 +22,15 @@
 # directories depending on the host environment and simplifies
 # cross-compilation.
 #
-# usage: configure.sh [-g] [{-d|-s <>}] [{-o|-m|-p}] -- [<configure-options>]
-#         -d  add debug compiler flags
-#         -s  add sanitiser compiler flags (eg. -s address)
-#         -o  cross-compile for openwrt (edit as required)
-#         -m  cross-compile for windows with mingw-w64
-#         -p  cross-compile for rpi
-#         -g  git-clone mbedtls
+# usage: configure.sh [-g] [{-d|-s <>}] [{-o|-w|-p}] -- [<configure-options>]
+#         -d   add debug compiler flags
+#         -s   add sanitiser compiler flags (eg. -s address)
+#         -o   cross-compile for openwrt (edit as required)
+#         -w   cross-compile for windows 32-bit with mingw-w64
+#         -w32 cross-compile for windows 32-bit with mingw-w64
+#         -w64 cross-compile for windows 64-bit with mingw-w64
+#         -p   cross-compile for rpi
+#         -g   git-clone mbedtls and exit
 #
 # For systemd add "e_systemddir=/usr/lib/systemd/system".
 #
@@ -39,16 +41,18 @@
 
 thisdir="`cd \`dirname $0\` && pwd`"
 
-usage="[-g] [{-d|-s <>}] [{-o|-m|-p}] -- <configure-args>"
+usage="[-g] [{-d|-s <>}] [{-o|-w|-p}] -- <configure-args>"
 while expr "x$1" : "x-" >/dev/null
 do
 	valued=0
-	case "`echo \"$1\" | sed 's/^-//'`" in
+	case "`echo \"$1\" | sed 's/^--*//'`" in
 		g) opt_git=1 ;;
 		d) opt_debug=1 ;;
 		s) opt_sanitise="$2" ; valued=1 ;;
 		o) opt_openwrt=1 ;;
-		m) opt_mingw=1 ;;
+		w) opt_mingw=1 ; opt_win=32 ;;
+		w32) opt_mingw=1 ; opt_win=32 ;;
+		w64) opt_mingw=1 ; opt_win=64 ;;
 		p) opt_rpi=1 ;;
 		h) echo usage: `basename $0` $usage "..." ; $thisdir/configure --help=short ; exit 0 ;;
 		#\?) echo usage: `basename $0` $usage >&2 ; exit 2 ;;
@@ -71,6 +75,14 @@ fi
 if test "0$opt_git" -eq 1
 then
 	git clone https://salsa.debian.org/debian/mbedtls.git
+	e="$?"
+	sed -i 's/defined._TRUNCATE./0/' mbedtls/library/platform.c
+	if test "$e" -eq 0 -a "0$opt_mingw" -eq 0
+	then
+		echo build with...
+		echo "  make -C mbedtls/library WINDOWS=0"
+	fi
+	exit "$e"
 fi
 
 enable_debug=""
@@ -105,16 +117,21 @@ then
 fi
 if test -d "$MBEDTLS_DIR"
 then
-	echo "configure.sh: mbedtls directory exists: adding --with-mbedtls and CPPFLAGS=-I$MBEDTLS_DIR/include etc"
+	echo "configure.sh: mbedtls directory exists: adding --with-mbedtls and CXXFLAGS=-I$MBEDTLS_DIR/include etc"
 	with_mbedtls="--with-mbedtls"
 	make_mbedtls=1
-	export CPPFLAGS="$CPPFLAGS -I`pwd`/$MBEDTLS_DIR/include"
+	export CXXFLAGS="$CXXFLAGS -I`pwd`/$MBEDTLS_DIR/include"
 	export LDFLAGS="$LDFLAGS -L`pwd`/$MBEDTLS_DIR/library"
 fi
 
 if test "0$opt_mingw" -eq 1
 then
-	TARGET="i686-w64-mingw32"
+	if test "$opt_win" -eq 32
+	then
+		TARGET="i686-w64-mingw32" # 32-bit binaries
+	else
+		TARGET="x86_64-w64-mingw32" # 64-bit binaries
+	fi
 	export CXX="$TARGET-g++-posix"
 	export CC="$TARGET-gcc-posix"
 	export AR="$TARGET-ar"
@@ -122,7 +139,7 @@ then
 	export GCONFIG_WINDMC="$TARGET-windmc"
 	export GCONFIG_WINDRES="$TARGET-windres"
 	export CXXFLAGS="$CXXFLAGS -std=c++11 -pthread"
-	#export CPPFLAGS="$CPPFLAGS -D_WIN32_WINNT=0x0501" eg. for Windows XP, otherwise whatever mingw defaults to
+	#export CXXFLAGS="$CXXFLAGS -D_WIN32_WINNT=0x0501" eg. for Windows XP, otherwise whatever mingw defaults to
 	export LDFLAGS="$LDFLAGS -pthread"
 	if test -x "`which $CXX`" ; then : ; else echo "error: no mingw c++ compiler: [$CXX]\n" ; exit 1 ; fi
 	( echo msbuild . ; echo qt-x86 . ; echo qt-x64 . ; echo cmake . ; echo msvc . ) > winbuild.cfg
@@ -167,35 +184,35 @@ then
 :
 elif test "0$opt_openwrt" -eq 1
 then
-    TARGET="mips-openwrt-linux-musl"
-    SDK_DIR="`find $HOME -maxdepth 3 -type d -iname openwrt-sdk\* 2>/dev/null | sort | head -1`"
-    SDK_TOOLCHAIN_DIR="`find \"$SDK_DIR/staging_dir\" -type d -iname toolchain-\* 2>/dev/null | sort | head -1`"
-    SDK_TARGET_DIR="`find \"$SDK_DIR/staging_dir\" -type d -iname target-\* 2>/dev/null | sort | head -1`"
-    export CC="$SDK_TOOLCHAIN_DIR/bin/$TARGET-gcc"
-    export CXX="$SDK_TOOLCHAIN_DIR/bin/$TARGET-c++"
-    export AR="$SDK_TOOLCHAIN_DIR/bin/$TARGET-ar"
-    export STRIP="$SDK_TOOLCHAIN_DIR/bin/$TARGET-strip"
-    export CXXFLAGS="-fno-rtti -fno-threadsafe-statics -Os $CXXFLAGS"
-    export CPPFLAGS="$CPPFLAGS -DG_SMALL"
+	TARGET="mips-openwrt-linux-musl"
+	SDK_DIR="`find $HOME -maxdepth 3 -type d -iname openwrt-sdk\* 2>/dev/null | sort | head -1`"
+	SDK_TOOLCHAIN_DIR="`find \"$SDK_DIR/staging_dir\" -type d -iname toolchain-\* 2>/dev/null | sort | head -1`"
+	SDK_TARGET_DIR="`find \"$SDK_DIR/staging_dir\" -type d -iname target-\* 2>/dev/null | sort | head -1`"
+	export CC="$SDK_TOOLCHAIN_DIR/bin/$TARGET-gcc"
+	export CXX="$SDK_TOOLCHAIN_DIR/bin/$TARGET-c++"
+	export AR="$SDK_TOOLCHAIN_DIR/bin/$TARGET-ar"
+	export STRIP="$SDK_TOOLCHAIN_DIR/bin/$TARGET-strip"
+	export CXXFLAGS="-fno-rtti -fno-threadsafe-statics -Os $CXXFLAGS"
+	export CXXFLAGS="$CXXFLAGS -DG_SMALL"
 	export LDFLAGS="$LDFLAGS -static"
 	export LIBS="-lgcc_eh"
 	if test -x "$CXX" ; then : ; else echo "error: no c++ compiler for target [$TARGET]: CXX=[$CXX]\n" ; exit 1 ; fi
-    $thisdir/configure $enable_debug --host $TARGET \
+	$thisdir/configure $enable_debug --host $TARGET \
 		--disable-gui --without-pam --without-doxygen \
 		$with_mbedtls --disable-std-thread \
 		--prefix=/usr --libexecdir=/usr/lib --sysconfdir=/etc \
 		--localstatedir=/var $opt_passthrough e_initdir=/etc/init.d "$@"
 	echo :
 	echo "build with..."
-    #echo "  export PATH=\"$SDK_TOOLCHAIN_DIR/bin:\$PATH\""
-    #echo "  export STAGING_DIR=\"$SDK_DIR/staging_dir\""
+	#echo "  export PATH=\"$SDK_TOOLCHAIN_DIR/bin:\$PATH\""
+	#echo "  export STAGING_DIR=\"$SDK_DIR/staging_dir\""
 	test "$make_mbedtls" -eq 1 && echo "  make -C $MBEDTLS_DIR/library CC=$CC AR=$AR"
 	echo "  make"
 	echo "  make -C src/main strip"
 :
 elif test "`uname`" = "NetBSD"
 then
-	export CPPFLAGS="$CPPFLAGS -I/usr/X11R7/include"
+	export CXXFLAGS="$CXXFLAGS -I/usr/X11R7/include"
 	export LDFLAGS="$LDFLAGS -L/usr/X11R7/lib"
 	$thisdir/configure $enable_debug $with_mbedtls \
 		--prefix=/usr --libexecdir=/usr/lib --sysconfdir=/etc \
@@ -203,7 +220,7 @@ then
 :
 elif test "`uname`" = "FreeBSD"
 then
-	export CPPFLAGS="$CPPFLAGS -I/usr/local/include -I/usr/local/include/libav"
+	export CXXFLAGS="$CXXFLAGS -I/usr/local/include -I/usr/local/include/libav"
 	export LDFLAGS="$LDFLAGS -L/usr/local/lib -L/usr/local/lib/libav"
 	$thisdir/configure $enable_debug $with_mbedtls \
 		--prefix=/usr/local --mandir=/usr/local/man \
@@ -211,7 +228,7 @@ then
 :
 elif test "`uname`" = "OpenBSD"
 then
-	export CPPFLAGS="$CPPFLAGS -I/usr/X11R6/include"
+	export CXXFLAGS="$CXXFLAGS -I/usr/X11R6/include"
 	export LDFLAGS="$LDFLAGS -L/usr/X11R6/lib"
 	$thisdir/configure $enable_debug $with_mbedtls \
 		--prefix=/usr/local --mandir=/usr/local/man \
@@ -219,14 +236,14 @@ then
 :
 elif test "`uname`" = "Darwin"
 then
-	export CPPFLAGS="$CPPFLAGS -I/opt/local/include -I/opt/X11/include"
+	export CXXFLAGS="$CXXFLAGS -I/opt/local/include -I/opt/X11/include"
 	export LDFLAGS="$LDFLAGS -L/opt/local/lib -L/opt/X11/lib"
 	$thisdir/configure $enable_debug $with_mbedtls \
 		--prefix=/opt/local --mandir=/opt/local/man $opt_passthrough "$@"
 :
 elif test "`uname`" = "Linux"
 then
-	export CPPFLAGS
+	export CXXFLAGS
 	export LDFLAGS
 	$thisdir/configure $enable_debug $with_mbedtls \
 		--prefix=/usr --libexecdir=/usr/lib --sysconfdir=/etc \
@@ -234,7 +251,7 @@ then
 		$opt_passthrough e_rundir=/run/emailrelay "$@"
 :
 else
-	export CPPFLAGS="$CPPFLAGS -I/usr/X11R7/include -I/usr/X11R6/include -I/usr/local/include -I/opt/local/include -I/opt/X11/include"
+	export CXXFLAGS="$CXXFLAGS -I/usr/X11R7/include -I/usr/X11R6/include -I/usr/local/include -I/opt/local/include -I/opt/X11/include"
 	export LDFLAGS="$LDFLAGS -L/usr/X11R7/lib -L/usr/X11R6/lib -L/usr/local/lib -L/opt/local/lib -L/opt/X11/lib"
 	$thisdir/configure $enable_debug $with_mbedtls $opt_passthrough "$@"
 fi
