@@ -20,6 +20,7 @@
 
 #include "gdef.h"
 #include "gcleanup.h"
+#include <cstring> // _strdup()
 
 void G::Cleanup::init()
 {
@@ -46,3 +47,20 @@ void G::Cleanup::release() noexcept
 	// not implemented
 }
 
+namespace
+{
+	const char * strdup_ignore_leaks( const char * p )
+	{
+		return _strdup( p ) ; // NOLINT
+	}
+}
+
+const char * G::Cleanup::strdup( const char * p )
+{
+	return strdup_ignore_leaks( p ) ;
+}
+
+const char * G::Cleanup::strdup( const std::string & s )
+{
+	return strdup_ignore_leaks( s.c_str() ) ;
+}
