@@ -700,6 +700,13 @@
 			#define GCONFIG_HAVE_PTHREAD_SIGMASK 0
 		#endif
 	#endif
+	#if !defined(GCONFIG_HAVE_UDS)
+		#ifdef G_UNIX
+			#define GCONFIG_HAVE_UDS 1
+		#else
+			#define GCONFIG_HAVE_UDS 0
+		#endif
+	#endif
 
 	/* Include early o/s headers
 	 */
@@ -1356,7 +1363,7 @@
 		#endif
 
 		#if ! GCONFIG_HAVE_CXX_ALIGNMENT
-			namespace std
+			namespace std // NOLINT
 			{
 				// missing in gcc 4.8.4 -- original copyright 2001-2016 FSF Inc, GPLv3
 				inline void * align( size_t align , size_t size , void * & ptr_inout , size_t & space ) noexcept
