@@ -1,22 +1,22 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
-//
-// gdirectory.cpp
-//
+///
+/// \file gdirectory.cpp
+///
 
 #include "gdef.h"
 #include "gdirectory.h"
@@ -26,7 +26,7 @@
 #include "gstr.h"
 #include "glog.h"
 #include <algorithm> // std::sort
-#include <functional> // std::ptr_fun
+#include <functional>
 #include <iterator> // std::distance
 
 G::Directory::Directory() :
@@ -58,17 +58,19 @@ std::string G::Directory::tmp()
 {
 	std::ostringstream ss ;
 	static int sequence = 1 ;
-	ss << "." << DateTime::now() << "." << sequence++ << "." << Process::Id() << ".tmp" ;
+	ss << "." << SystemTime::now() << "." << sequence++ << "." << Process::Id() << ".tmp" ;
 	return ss.str() ;
 }
 
+bool G::Directory::valid( bool for_creation ) const
+{
+	return 0 == usable( for_creation ) ;
+}
+
 // ==
 
-G::DirectoryList::DirectoryList() :
-	m_first(true) ,
-	m_index(0U)
-{
-}
+G::DirectoryList::DirectoryList()
+= default;
 
 void G::DirectoryList::readAll( const G::Path & dir , std::vector<G::DirectoryList::Item> & out , bool sorted )
 {
@@ -145,7 +147,6 @@ bool G::DirectoryList::compare( const Item & a , const Item & b )
 
 void G::DirectoryList::sort()
 {
-	std::sort( m_list.begin() , m_list.end() , std::ptr_fun(compare) ) ;
+	std::sort( m_list.begin() , m_list.end() , compare ) ;
 }
 
-/// \file gdirectory.cpp
