@@ -542,10 +542,10 @@ public:
 			///< in the match-list (blocklist). (Removes nothing if the match-list is
 			///< empty.) Returns an iterator for erase().
 
-	static constexpr size_t truncate = (~(static_cast<std::size_t>(0U))) ;
+	static constexpr std::size_t truncate = (~(static_cast<std::size_t>(0U))) ;
 		///< A special value for the G::Str::strncpy_s() 'count' parameter.
 
-	static errno_t strncpy_s( char * dst , size_t n_dst , const char * src , size_t count ) noexcept ;
+	static errno_t strncpy_s( char * dst , std::size_t n_dst , const char * src , std::size_t count ) noexcept ;
 		///< Does the same as windows strncpy_s(). Copies count characters
 		///< from src to dst and adds a terminator character, but fails
 		///< if dst is too small. If the count is 'truncate' then as
