@@ -37,30 +37,30 @@ class GNet::Address4
 {
 public:
 	using sockaddr_type = sockaddr_in ;
-	using storage_type = sockaddr_storage ;
 
 	explicit Address4( unsigned int ) ;
 	explicit Address4( const std::string & ) ;
 	Address4( const std::string & , const std::string & ) ;
 	Address4( const std::string & , unsigned int ) ;
-	Address4( unsigned int port , int /*for overload resolution*/ ) ; // canonical loopback address
-	Address4( const sockaddr * addr , socklen_t len ) ;
+	Address4( unsigned int port , int /*loopback_overload*/ ) ; // canonical loopback address
+	Address4( const sockaddr * addr , socklen_t len , bool ipv6_scope_id_fixup = false ) ;
 
-	static int domain() ;
-	static unsigned short family() ;
+	static int domain() noexcept ;
+	static unsigned short af() noexcept ;
 	const sockaddr * address() const ;
 	sockaddr * address() ;
 	static socklen_t length() noexcept ;
-
+	unsigned long scopeId( unsigned long default_ = 0UL ) const ;
 	unsigned int port() const ;
 	void setPort( unsigned int port ) ;
-
+	bool setZone( const std::string & ipv6_zone_name_or_scope_id ) ;
+	void setScopeId( unsigned long ipv6_scope_id ) ;
 	static bool validString( const std::string & , std::string * = nullptr ) ;
 	static bool validStrings( const std::string & , const std::string & , std::string * = nullptr ) ;
 	static bool validPort( unsigned int port ) ;
 	static bool validData( const sockaddr * addr , socklen_t len ) ;
 
-	bool same( const Address4 & other ) const ;
+	bool same( const Address4 & other , bool ipv6_compare_with_scope = false ) const ;
 	bool sameHostPart( const Address4 & other ) const ;
 	bool isLoopback() const ;
 	bool isLocal( std::string & ) const ;
@@ -68,8 +68,8 @@ public:
 	bool isUniqueLocal() const ;
 	bool isAny() const ;
 	unsigned int bits() const ;
-	std::string displayString() const ;
-	std::string hostPartString() const ;
+	std::string displayString( bool ipv6_with_scope = false ) const ;
+	std::string hostPartString( bool raw = false ) const ;
 	std::string queryString() const ;
 	G::StringArray wildcards() const ;
 	static bool format( std::string ) ;
