@@ -37,40 +37,39 @@ class GNet::Address6
 {
 public:
 	using sockaddr_type = sockaddr_in6 ;
-	using storage_type = sockaddr_storage ;
 
 	explicit Address6( unsigned int ) ;
 	explicit Address6( const std::string & ) ;
 	Address6( const std::string & , const std::string & ) ;
 	Address6( const std::string & , unsigned int ) ;
 	Address6( unsigned int port , int /*for overload resolution*/ ) ; // canonical loopback address
-	Address6( const sockaddr * addr , socklen_t len , bool = false ) ;
+	Address6( const sockaddr * addr , socklen_t len , bool ipv6_scope_id_fixup = false ) ;
 
-	static int domain() ;
-	static unsigned short family() ;
+	static int domain() noexcept ;
+	static unsigned short af() noexcept ;
 	const sockaddr * address() const ;
 	sockaddr * address() ;
 	static socklen_t length() noexcept ;
-	unsigned long scopeId() const ;
+	unsigned long scopeId( unsigned long default_ = 0UL ) const ;
 	unsigned int port() const ;
 	void setPort( unsigned int port ) ;
-	bool setZone( const std::string & zone_name_or_scope_id ) ;
-	void setScopeId( unsigned long ) ;
+	bool setZone( const std::string & ipv6_zone_name_or_scope_id ) ;
+	void setScopeId( unsigned long ipv6_scope_id ) ;
 	static bool validString( const std::string & , std::string * = nullptr ) ;
 	static bool validStrings( const std::string & , const std::string & , std::string * = nullptr ) ;
 	static bool validPort( unsigned int port ) ;
 	static bool validData( const sockaddr * addr , socklen_t len ) ;
 
-	bool same( const Address6 & other , bool with_scope = false ) const ;
-	bool sameHostPart( const Address6 & other , bool with_scope = false ) const ;
+	bool same( const Address6 & other , bool ipv6_compare_with_scope = false ) const ;
+	bool sameHostPart( const Address6 & other , bool ipv6_compare_with_scope = false ) const ;
 	bool isLoopback() const ;
 	bool isLocal( std::string & ) const ;
 	bool isLinkLocal() const ;
 	bool isUniqueLocal() const ;
 	bool isAny() const ;
 	unsigned int bits() const ;
-	std::string displayString( bool ) const ;
-	std::string hostPartString() const ;
+	std::string displayString( bool ipv6_with_scope = false ) const ;
+	std::string hostPartString( bool raw = false ) const ;
 	std::string queryString() const ;
 	G::StringArray wildcards() const ;
 
