@@ -1,16 +1,16 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
@@ -18,8 +18,8 @@
 /// \file geventhandler.h
 ///
 
-#ifndef G_NET_EVENT_HANDLER__H
-#define G_NET_EVENT_HANDLER__H
+#ifndef G_NET_EVENT_HANDLER_H
+#define G_NET_EVENT_HANDLER_H
 
 #include "gdef.h"
 #include "gdatetime.h"
@@ -33,7 +33,7 @@ namespace GNet
 	class EventHandler ;
 }
 
-/// \class GNet::EventHandler
+//| \class GNet::EventHandler
 /// A base class for classes that handle asynchronous events from the
 /// event loop.
 ///
@@ -47,16 +47,16 @@ namespace GNet
 class GNet::EventHandler
 {
 public:
-	g__enum(Reason)
+	enum class Reason
 	{
 		closed , // fin packet, clean shutdown
 		down , // network down
 		reset , // rst packet
 		abort , // socket failed
 		other // eg. oob data
-	} ; g__enum_end(Reason)
+	} ;
 
-	virtual ~EventHandler() ;
+	virtual ~EventHandler() = default ;
 		///< Destructor.
 
 	virtual void readEvent() ;
