@@ -1,22 +1,22 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
-//
-// geventloop.cpp
-//
+///
+/// \file geventloop.cpp
+///
 
 #include "gdef.h"
 #include "geventloop.h"
@@ -39,11 +39,15 @@ GNet::EventLoop::~EventLoop()
 		m_this = nullptr ;
 }
 
+GNet::EventLoop * GNet::EventLoop::ptr() noexcept
+{
+	return m_this ;
+}
+
 GNet::EventLoop & GNet::EventLoop::instance()
 {
 	if( m_this == nullptr )
 		throw NoInstance() ;
-	G_ASSERT( m_this != nullptr ) ;
 	return *m_this ;
 }
 
@@ -58,4 +62,3 @@ void GNet::EventLoop::stop( const G::SignalSafe & signal_safe )
 		m_this->quit( signal_safe ) ;
 }
 
-/// \file geventloop.cpp
