@@ -1,22 +1,22 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
-//
-// gmonitor.cpp
-//
+///
+/// \file gmonitor.cpp
+///
 
 #include "gdef.h"
 #include "gmonitor.h"
@@ -27,61 +27,64 @@
 #include <algorithm> // std::swap()
 #include <utility> // std::swap()
 
-/// \class GNet::MonitorImp
+//| \class GNet::MonitorImp
 /// A pimple-pattern implementation class for GNet::Monitor.
 ///
 class GNet::MonitorImp
 {
 public:
+	using Signal = G::Slot::Signal<const std::string&,const std::string&> ;
 	explicit MonitorImp( Monitor & monitor ) ;
 	void add( const Connection & , bool is_client ) ;
-	void remove( const Connection & , bool is_client ) ;
+	void remove( const Connection & , bool is_client ) noexcept ;
+	void add( const Listener & ) ;
+	void remove( const Listener & ) noexcept ;
 	void report( std::ostream & s , const std::string & px , const std::string & eol ) const ;
 	void report( G::StringArray & ) const ;
+	void emit( Signal & , const char * , const char * ) noexcept ;
 
 private:
 	struct ConnectionInfo
 	{
 		bool is_client ;
-		explicit ConnectionInfo( bool is_client_ ) : is_client(is_client_) {}
+		explicit ConnectionInfo( bool is_client_ ) noexcept : is_client(is_client_) {}
 	} ;
-	typedef std::map<const Connection*,ConnectionInfo> ConnectionMap ;
+	using ConnectionMap = std::map<const Connection*,ConnectionInfo> ;
+	using ServerMap = std::map<const Listener*,Address> ;
+
+public:
+	~MonitorImp() = default ;
+	MonitorImp( const MonitorImp & ) = delete ;
+	MonitorImp( MonitorImp && ) = delete ;
+	void operator=( const MonitorImp & ) = delete ;
+	void operator=( MonitorImp && ) = delete ;
 
 private:
-	MonitorImp( const MonitorImp & ) g__eq_delete ;
-	void operator=( const MonitorImp & ) g__eq_delete ;
 	static std::string join( const std::string & , const std::string & ) ;
 	static void add( G::StringArray & , const std::string & , unsigned int , const std::string & ,
 		unsigned int , const std::string & ) ;
 	static void add( G::StringArray & , const std::string & , const std::string & , const std::string & ,
 		const std::string & , const std::string & ) ;
+	static void add( G::StringArray & , const std::string & , const std::string & , const std::string & ) ;
+	static void add( G::StringArray & , const std::string & , const std::string & ) ;
 
 private:
 	ConnectionMap m_connections ;
+	ServerMap m_servers ;
 	unsigned long m_client_adds ;
 	unsigned long m_client_removes ;
 	unsigned long m_server_peer_adds ;
 	unsigned long m_server_peer_removes ;
 } ;
 
-GNet::MonitorImp::MonitorImp( Monitor & ) :
-	m_client_adds(0UL) ,
-	m_client_removes(0UL) ,
-	m_server_peer_adds(0UL) ,
-	m_server_peer_removes(0UL)
-{
-}
-
-// ===
-
-GNet::Monitor * & GNet::Monitor::pthis()
+GNet::Monitor * & GNet::Monitor::pthis() noexcept
 {
 	static GNet::Monitor * p = nullptr ;
 	return p ;
 }
 
 GNet::Monitor::Monitor() :
-	m_imp( new MonitorImp(*this) )
+	m_imp(std::make_unique<MonitorImp>(*this))
 {
 	G_ASSERT( pthis() == nullptr ) ;
 	pthis() = this ;
@@ -97,7 +100,7 @@ GNet::Monitor * GNet::Monitor::instance()
 	return pthis() ;
 }
 
-G::Slot::Signal2<std::string,std::string> & GNet::Monitor::signal()
+G::Slot::Signal<const std::string&,const std::string&> & GNet::Monitor::signal()
 {
 	return m_signal ;
 }
@@ -107,16 +110,16 @@ void GNet::Monitor::addClient( const Connection & client )
 	if( pthis() )
 	{
 		pthis()->m_imp->add( client , true ) ;
-		pthis()->m_signal.emit( "out" , "start" ) ;
+		pthis()->m_imp->emit( pthis()->m_signal , "out" , "start" ) ;
 	}
 }
 
-void GNet::Monitor::removeClient( const Connection & client )
+void GNet::Monitor::removeClient( const Connection & client ) noexcept
 {
 	if( pthis() )
 	{
 		pthis()->m_imp->remove( client , true ) ;
-		pthis()->m_signal.emit( "out" , "end" ) ;
+		pthis()->m_imp->emit( pthis()->m_signal , "out" , "stop" ) ;
 	}
 }
 
@@ -125,17 +128,35 @@ void GNet::Monitor::addServerPeer( const Connection & server_peer )
 	if( pthis() )
 	{
 		pthis()->m_imp->add( server_peer , false ) ;
-		pthis()->m_signal.emit( "in" , "start" ) ;
+		pthis()->m_imp->emit( pthis()->m_signal , "in" , "start" ) ;
 	}
 }
 
 
-void GNet::Monitor::removeServerPeer( const Connection & server_peer )
+void GNet::Monitor::removeServerPeer( const Connection & server_peer ) noexcept
 {
 	if( pthis() )
 	{
 		pthis()->m_imp->remove( server_peer , false ) ;
-		pthis()->m_signal.emit( "in" , "end" ) ;
+		pthis()->m_imp->emit( pthis()->m_signal , "in" , "stop" ) ;
+	}
+}
+
+void GNet::Monitor::addServer( const Listener & server )
+{
+	if( pthis() )
+	{
+		pthis()->m_imp->add( server ) ;
+		pthis()->m_imp->emit( pthis()->m_signal , "listen" , "start" ) ;
+	}
+}
+
+void GNet::Monitor::removeServer( const Listener & server ) noexcept
+{
+	if( pthis() )
+	{
+		pthis()->m_imp->remove( server ) ;
+		pthis()->m_imp->emit( pthis()->m_signal , "listen" , "stop" ) ;
 	}
 }
 
@@ -151,6 +172,14 @@ void GNet::Monitor::report( G::StringArray & out ) const
 
 // ==
 
+GNet::MonitorImp::MonitorImp( Monitor & ) :
+	m_client_adds(0UL) ,
+	m_client_removes(0UL) ,
+	m_server_peer_adds(0UL) ,
+	m_server_peer_removes(0UL)
+{
+}
+
 void GNet::MonitorImp::add( const Connection & connection , bool is_client )
 {
 	bool inserted = m_connections.insert(ConnectionMap::value_type(&connection,ConnectionInfo(is_client))).second ;
@@ -163,9 +192,25 @@ void GNet::MonitorImp::add( const Connection & connection , bool is_client )
 	}
 }
 
-void GNet::MonitorImp::remove( const Connection & connection , bool is_client )
+void GNet::MonitorImp::add( const Listener & server )
 {
-	bool removed = 0U != m_connections.erase( &connection ) ;
+	m_servers.insert( ServerMap::value_type(&server,server.address()) ) ;
+}
+
+void GNet::MonitorImp::emit( Signal & s , const char * a , const char * b ) noexcept
+{
+	try
+	{
+		s.emit( std::string(a) , std::string(b) ) ;
+	}
+	catch(...)
+	{
+	}
+}
+
+void GNet::MonitorImp::remove( const Connection & connection , bool is_client ) noexcept
+{
+	bool removed = 0U != m_connections.erase( &connection ) ; // noexcept since trivial Compare
 	if( removed )
 	{
 		if( is_client )
@@ -175,19 +220,29 @@ void GNet::MonitorImp::remove( const Connection & connection , bool is_client )
 	}
 }
 
+void GNet::MonitorImp::remove( const Listener & server ) noexcept
+{
+	m_servers.erase( &server ) ; // noexcept since trivial Compare
+}
+
 void GNet::MonitorImp::report( std::ostream & s , const std::string & px , const std::string & eol ) const
 {
+	for( const auto & server : m_servers )
+	{
+		s << px << "LISTEN: " << server.second.displayString(true) << eol ;
+	}
+
 	s << px << "OUT started: " << m_client_adds << eol ;
 	s << px << "OUT finished: " << m_client_removes << eol ;
 	{
-		for( ConnectionMap::const_iterator p = m_connections.begin() ; p != m_connections.end() ; ++p )
+		for( const auto & connection : m_connections )
 		{
-			if( (*p).second.is_client )
+			if( connection.second.is_client )
 			{
 				s << px
 					<< "OUT: "
-					<< (*p).first->localAddress().second.displayString() << " -> "
-					<< (*p).first->connectionState() << eol ;
+					<< connection.first->localAddress().second.displayString() << " -> "
+					<< connection.first->connectionState() << eol ;
 			}
 		}
 	}
@@ -195,14 +250,14 @@ void GNet::MonitorImp::report( std::ostream & s , const std::string & px , const
 	s << px << "IN started: " << m_server_peer_adds << eol ;
 	s << px << "IN finished: " << m_server_peer_removes << eol ;
 	{
-		for( ConnectionMap::const_iterator p = m_connections.begin() ; p != m_connections.end() ; ++p )
+		for( const auto & connection : m_connections )
 		{
-			if( !(*p).second.is_client )
+			if( !connection.second.is_client )
 			{
 				s << px
 					<< "IN: "
-					<< (*p).first->localAddress().second.displayString() << " <- "
-					<< (*p).first->peerAddress().second.displayString() << eol ;
+					<< connection.first->localAddress().second.displayString() << " <- "
+					<< connection.first->peerAddress().second.displayString() << eol ;
 			}
 		}
 	}
@@ -210,21 +265,24 @@ void GNet::MonitorImp::report( std::ostream & s , const std::string & px , const
 
 void GNet::MonitorImp::report( G::StringArray & out ) const
 {
+	for( const auto & server : m_servers )
+		add( out , "Listening address" , server.second.displayString() ) ;
+
 	add( out , "Outgoing connections" , m_client_adds , "started" , m_client_removes , "finished" ) ;
 	add( out , "Incoming connections" , m_server_peer_adds , "started" , m_server_peer_removes , "finished" ) ;
-	for( ConnectionMap::const_iterator p = m_connections.begin() ; p != m_connections.end() ; ++p )
+	for( const auto & connection : m_connections )
 	{
-		if( (*p).second.is_client )
+		if( connection.second.is_client )
 		{
-			add( out , "Outgoing connection" , (*p).first->localAddress().second.displayString() , "-->" ,
-				(*p).first->connectionState() , "" ) ;
+			add( out , "Outgoing connection" , connection.first->localAddress().second.displayString() , "-->" ,
+				connection.first->connectionState() , "" ) ;
 		}
 	}
-	for( ConnectionMap::const_iterator p = m_connections.begin() ; p != m_connections.end() ; ++p )
+	for( const auto & connection : m_connections )
 	{
-		if( !(*p).second.is_client )
-			add( out , "Incoming connection" , (*p).first->localAddress().second.displayString() , "<--" ,
-				(*p).first->peerAddress().second.displayString() , "" ) ;
+		if( !connection.second.is_client )
+			add( out , "Incoming connection" , connection.first->localAddress().second.displayString() , "<--" ,
+				connection.first->peerAddress().second.displayString() , "" ) ;
 	}
 }
 
@@ -235,17 +293,28 @@ void GNet::MonitorImp::add( G::StringArray & out , const std::string & key ,
 	add( out , key , G::Str::fromUInt(value_1) , suffix_1 , G::Str::fromUInt(value_2) , suffix_2 ) ;
 }
 
+void GNet::MonitorImp::add( G::StringArray & out , const std::string & key ,
+	const std::string & value_1 , const std::string & suffix_1 ,
+	const std::string & value_2 , const std::string & suffix_2 )
+{
+	add( out , key , join(value_1,suffix_1) , join(value_2,suffix_2) ) ;
+}
+
+void GNet::MonitorImp::add( G::StringArray & out , const std::string & key , const std::string & value )
+{
+	add( out , key , value , std::string() ) ;
+}
+
+void GNet::MonitorImp::add( G::StringArray & out , const std::string & key , const std::string & value_1 ,
+	const std::string & value_2 )
+{
+	out.push_back( key ) ;
+	out.push_back( value_1 ) ;
+	out.push_back( value_2 ) ;
+}
+
 std::string GNet::MonitorImp::join( const std::string & s1 , const std::string & s2 )
 {
 	return s2.empty() ? s1 : ( s1 + " " + s2 ) ;
 }
 
-void GNet::MonitorImp::add( G::StringArray & out , const std::string & key ,
-	const std::string & value_1 , const std::string & suffix_1 ,
-	const std::string & value_2 , const std::string & suffix_2 )
-{
-	out.push_back( key ) ;
-	out.push_back( join(value_1,suffix_1) ) ;
-	out.push_back( join(value_2,suffix_2) ) ;
-}
-
