@@ -32,6 +32,7 @@
 #include "glog.h"
 #include <memory>
 #include <numeric>
+#include <algorithm>
 
 //| \class GNet::SocketProtocolImp
 /// A pimple-pattern implementation class used by GNet::SocketProtocol.
@@ -165,9 +166,7 @@ GNet::SocketProtocolImp::~SocketProtocolImp()
 
 void GNet::SocketProtocolImp::setReadBufferSize( std::size_t n )
 {
-	m_read_buffer_size = n ;
-	if( m_read_buffer_size == 0U )
-		m_read_buffer_size = 1U ;
+	m_read_buffer_size = std::max( std::size_t(1U) , n ) ;
 }
 
 void GNet::SocketProtocolImp::onSecureConnectionTimeout()
@@ -293,7 +292,7 @@ bool GNet::SocketProtocolImp::send( const std::string & data , std::size_t offse
 
 bool GNet::SocketProtocolImp::send( const Segments & segments , std::size_t offset )
 {
-	if( segments.empty() || size(segments) == 0U )
+	if( segments.empty() || size(segments) == 0U || offset >= size(segments) )
 		return true ;
 
 	bool rc = true ;
