@@ -34,15 +34,14 @@
 #include <string>
 #include <tuple>
 
-GSmtp::ServerProtocol::ServerProtocol( GNet::ExceptionSink es , Sender & sender ,
+GSmtp::ServerProtocol::ServerProtocol( Sender & sender ,
 	Verifier & verifier , ProtocolMessage & pmessage ,
-	const GAuth::Secrets & secrets , const std::string & sasl_server_config ,
+	const GAuth::SaslServerSecrets & secrets , const std::string & sasl_server_config ,
 	Text & text , const GNet::Address & peer_address , const Config & config ) :
 		m_sender(sender) ,
 		m_verifier(verifier) ,
 		m_text(text) ,
 		m_message(pmessage) ,
-		m_process_timer(*this,&ServerProtocol::onProcessTimeout,es) ,
 		m_sasl(GAuth::SaslServerFactory::newSaslServer(secrets,sasl_server_config,false/*apop*/)) ,
 		m_config(config) ,
 		m_fsm(State::sStart,State::sEnd,State::s_Same,State::s_Any) ,
@@ -87,7 +86,6 @@ GSmtp::ServerProtocol::ServerProtocol( GNet::ExceptionSink es , Sender & sender
 	m_fsm( Event::eContent , State::sData , State::sData , &ServerProtocol::doContent , State::sDiscarding ) ;
 	m_fsm( Event::eEot , State::sData , State::sProcessing , &ServerProtocol::doEot ) ;
 	m_fsm( Event::eDone , State::sProcessing , State::sIdle , &ServerProtocol::doComplete ) ;
-	m_fsm( Event::eTimeout , State::sProcessing , State::sIdle , &ServerProtocol::doComplete ) ;
 	m_fsm( Event::eContent , State::sDiscarding , State::sDiscarding , &ServerProtocol::doDiscard ) ;
 	m_fsm( Event::eEot , State::sDiscarding , State::sIdle , &ServerProtocol::doDiscarded ) ;
 
@@ -248,19 +246,14 @@ void GSmtp::ServerProtocol::doEot( EventData , bool & )
 {
 	G_LOG( "GSmtp::ServerProtocol: rx<<: [message content not logged]" ) ;
 	G_LOG( "GSmtp::ServerProtocol: rx<<: \".\"" ) ;
-	if( m_config.filter_timeout != 0U )
-	{
-		G_DEBUG( "GSmtp::ServerProtocol: starting filter timer: " << m_config.filter_timeout ) ;
-		m_process_timer.startTimer( m_config.filter_timeout ) ;
-	}
 	m_message.process( m_sasl->id() , m_peer_address.hostPartString() , m_certificate ) ;
 }
 
-void GSmtp::ServerProtocol::processDone( bool success , unsigned long id ,
+void GSmtp::ServerProtocol::processDone( bool success , const MessageId & id ,
 	const std::string & response , const std::string & reason )
 {
 	GDEF_IGNORE_PARAMS( success , id , reason ) ;
-	G_DEBUG( "GSmtp::ServerProtocol::processDone: " << (success?1:0) << " " << id
+	G_DEBUG( "GSmtp::ServerProtocol::processDone: " << (success?1:0) << " " << id.str()
 		<< " [" << response << "] [" << reason << "]" ) ;
 	G_ASSERT( success == response.empty() ) ;
 
@@ -269,16 +262,6 @@ void GSmtp::ServerProtocol::processDone( bool success , unsigned long id ,
 		throw ProtocolDone( "protocol error" ) ;
 }
 
-void GSmtp::ServerProtocol::onProcessTimeout()
-{
-	G_WARNING( "GSmtp::ServerProtocol::onProcessTimeout: message filter timed out after "
-		<< m_config.filter_timeout << "s" ) ;
-	std::string response = "timed out" ;
-	State new_state = m_fsm.apply( *this , Event::eTimeout , EventData(response.data(),response.size()) ) ;
-	if( new_state == State::s_Any )
-		throw ProtocolDone( "protocol error" ) ;
-}
-
 void GSmtp::ServerProtocol::doComplete( EventData event_data , bool & )
 {
 	reset() ;
@@ -375,13 +358,13 @@ void GSmtp::ServerProtocol::verify( const std::string & to , const std::string &
 	m_verifier.verify( to , from , m_peer_address , mechanism , id ) ;
 }
 
-void GSmtp::ServerProtocol::verifyDone( const std::string & mbox , const VerifierStatus & status )
+void GSmtp::ServerProtocol::verifyDone( const VerifierStatus & status )
 {
-	G_DEBUG( "GSmtp::ServerProtocol::verifyDone: verify done: [" << status.str(mbox) << "]" ) ;
+	G_DEBUG( "GSmtp::ServerProtocol::verifyDone: verify done: [" << status.str() << "]" ) ;
 	if( status.abort )
 		throw ProtocolDone( "address verifier abort" ) ; // denial-of-service countermeasure
 
-	std::string status_str = status.str( mbox ) ;
+	std::string status_str = status.str() ;
 	State new_state = m_fsm.apply( *this , Event::eVrfyReply , EventData(status_str.data(),status_str.size()) ) ;
 	if( new_state == State::s_Any )
 		throw ProtocolDone( "protocol error" ) ;
@@ -390,13 +373,12 @@ void GSmtp::ServerProtocol::verifyDone( const std::string & mbox , const Verifie
 void GSmtp::ServerProtocol::doVrfyReply( EventData event_data , bool & )
 {
 	std::string line( event_data.ptr , event_data.size ) ;
-	std::string mbox ;
-	VerifierStatus status = VerifierStatus::parse( line , mbox ) ;
+	VerifierStatus status = VerifierStatus::parse( line ) ;
 
 	if( status.is_valid && status.is_local )
 		sendVerified( status.full_name ) ; // 250
 	else if( status.is_valid )
-		sendWillAccept( mbox ) ; // 252
+		sendWillAccept( status.recipient ) ; // 252
 	else
 		sendNotVerified( status.response , status.temporary ) ; // 550 or 450
 }
@@ -588,7 +570,8 @@ void GSmtp::ServerProtocol::doMail( EventData event_data , bool & predicate )
 		std::string from_address ;
 		std::string from_error_response ;
 		std::tie(from_address,from_error_response) = parseMailFrom( line ) ;
-		bool ok = from_error_response.empty() && m_message.setFrom( from_address , parseMailAuth(line) ) ;
+		bool ok = from_error_response.empty() ;
+		m_message.setFrom( from_address , parseMailAuth(line) ) ;
 		predicate = ok ;
 		if( ok )
 		{
@@ -620,10 +603,9 @@ void GSmtp::ServerProtocol::doRcpt( EventData event_data , bool & predicate )
 
 void GSmtp::ServerProtocol::doVrfyToReply( EventData event_data , bool & predicate )
 {
-	std::string to ;
-	VerifierStatus status = VerifierStatus::parse( std::string(event_data.ptr,event_data.size) , to ) ;
+	VerifierStatus status = VerifierStatus::parse( std::string(event_data.ptr,event_data.size) ) ;
 
-	bool ok = m_message.addTo( to , status ) ;
+	bool ok = m_message.addTo( status ) ;
 	if( ok )
 	{
 		sendRcptReply() ;
@@ -643,7 +625,6 @@ void GSmtp::ServerProtocol::doUnknown( EventData event_data , bool & )
 void GSmtp::ServerProtocol::reset()
 {
 	// cancel the current message transaction -- ehlo/quit session unaffected
-	m_process_timer.cancelTimer() ;
 	m_message.clear() ;
 	m_verifier.cancel() ;
 }
