@@ -1,36 +1,29 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
-//
-// gstoredmessage.cpp
-//
+///
+/// \file gstoredmessage.cpp
+///
 
 #include "gdef.h"
 #include "gstoredmessage.h"
 
-GSmtp::StoredMessage::~StoredMessage()
-{
-}
-
 GSmtp::StoredMessageStub::StoredMessageStub()
-{
-}
+= default;
 
 GSmtp::StoredMessageStub::~StoredMessageStub()
-{
-}
+= default;
 
-/// \file gstoredmessage.cpp
