@@ -1,16 +1,16 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
@@ -18,8 +18,8 @@
 /// \file access.h
 ///
 
-#ifndef G_INSTALLER_ACCESS_H
-#define G_INSTALLER_ACCESS_H
+#ifndef G_MAIN_GUI_INSTALLER_ACCESS_H
+#define G_MAIN_GUI_INSTALLER_ACCESS_H
 
 #include "gdef.h"
 #include "gpath.h"
@@ -27,7 +27,7 @@
 #include "gstrings.h"
 #include <string>
 
-/// \class Access
+//| \class Access
 /// A static class for modifying file-system permissions.
 ///
 class Access
@@ -37,9 +37,8 @@ public:
 		///< Modifies the permissions on the given path in
 		///< some undefined way. Returns false on error.
 
-private:
-	Access( const Access & ) ;
-	void operator=( const Access & ) ;
+public:
+	Access() = delete ;
 } ;
 
 #endif
