@@ -1,28 +1,33 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
-//
-// dir_win32.cpp
-//
+///
+/// \file dir_win32.cpp
+///
 
 #include "gdef.h"
 #include "gconvert.h"
+#include "dir.h"
+#include "gfile.h"
+#include "gpath.h"
+#include "glog.h"
+#include <stdexcept>
+#include <vector>
 #include <shlwapi.h>
 #include <shlobj.h>
-#include <vector>
 
 #ifndef SHGFP_TYPE_CURRENT
 #define SHGFP_TYPE_CURRENT 0
@@ -34,12 +39,6 @@
 #define CSIDL_PROGRAM_FILESX86 42
 #endif
 
-#include "dir.h"
-#include "gfile.h"
-#include "gpath.h"
-#include "glog.h"
-#include <stdexcept>
-
 G::Path Dir::os_install()
 {
 	return special("programs") + "E-MailRelay" ;
@@ -86,10 +85,12 @@ G::Path Dir::special( const std::string & type )
 	// this is not quite right when running with UAC administrator rights because
 	// it gets the administrator's user directories for the desktop etc links and not
 	// the user's -- and there is no reasonable way to get the user's access token
-	char buffer[MAX_PATH] = { 0 } ;
-	HANDLE user_token = NULL ; // TODO original user's paths when run-as administrator
-	bool ok = S_OK == ::SHGetFolderPathA( NULL , special_id(type) , user_token , SHGFP_TYPE_CURRENT , buffer ) ;
-	return ok ? G::Path(buffer) : G::Path("c:/") ;
+	std::vector<char> buffer( MAX_PATH+1U ) ;
+	buffer.at(0) = '\0' ;
+	HANDLE user_token = HNULL ; // TODO original user's paths when run-as administrator
+	bool ok = S_OK == SHGetFolderPathA( HNULL , special_id(type) , user_token , SHGFP_TYPE_CURRENT , &buffer[0] ) ;
+	buffer.at(buffer.size()-1U) = '\0' ;
+	return ok ? G::Path(&buffer[0]) : G::Path("c:/") ;
 }
 
 G::Path Dir::home()
@@ -97,4 +98,3 @@ G::Path Dir::home()
 	return envPath( "USERPROFILE" , envPath( "HOME" , desktop() ) ) ;
 }
 
-/// \file dir_win32.cpp
