@@ -1,16 +1,16 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
@@ -18,8 +18,8 @@
 /// \file glink.h
 ///
 
-#ifndef G_LINK_H
-#define G_LINK_H
+#ifndef G_MAIN_GUI_LINK_H
+#define G_MAIN_GUI_LINK_H
 
 #include "gdef.h"
 #include "gpath.h"
@@ -27,22 +27,26 @@
 #include "gstrings.h"
 #include <string>
 
-class GLinkImp ;
+namespace G
+{
+	class Link ;
+	class LinkImp ;
+}
 
-/// \class GLink
+//| \class G::Link
 /// A class for creating desktop links (aka "shortcuts") and
 /// application menu items.
 ///
-class GLink
+class G::Link
 {
 public:
 	G_EXCEPTION( SaveError , "error saving desktop or menu link" ) ;
 
-	g__enum(Show) { Default , Hide } ; g__enum_end(Show)
+	enum class Show { Default , Hide } ;
 
-	GLink( const G::Path & target_path , const std::string & name , const std::string & description ,
-		const G::Path & working_dir , const G::StringArray & args = G::StringArray() ,
-		const G::Path & icon_source = G::Path() , Show show = Show::Default ,
+	Link( const Path & target_path , const std::string & name , const std::string & description ,
+		const Path & working_dir , const StringArray & args = StringArray() ,
+		const Path & icon_source = Path() , Show show = Show::Default ,
 		const std::string & internal_comment_1 = std::string() ,
 		const std::string & internal_comment_2 = std::string() ,
 		const std::string & internal_comment_3 = std::string() ) ;
@@ -54,24 +58,26 @@ public:
 	static std::string filename( const std::string & name ) ;
 		///< Returns a normalised filename including an extension like ".lnk" or ".desktop".
 
-	void saveAs( const G::Path & link_path ) ;
+	void saveAs( const Path & link_path ) ;
 		///< Saves the link.
 
-	~GLink() ;
+	~Link() ;
 		///< Destructor.
 
-	static bool remove( const G::Path & link_path ) ;
+	static bool remove( const Path & link_path ) ;
 		///< Removes a link. Returns true if removed.
 
-	static bool exists( const G::Path & link_path ) ;
+	static bool exists( const Path & link_path ) ;
 		///< Returns true if the link exists.
 
-private:
-	GLink( const GLink & ) ;
-	void operator=( const GLink & ) ;
+public:
+	Link( const Link & ) = delete ;
+	Link( Link && ) = delete ;
+	void operator=( const Link & ) = delete ;
+	void operator=( Link && ) = delete ;
 
 private:
-	GLinkImp * m_imp ;
+	std::unique_ptr<LinkImp> m_imp ;
 } ;
 
 #endif
