@@ -45,19 +45,18 @@ G::MapFile ServerConfiguration::read( const G::Path & config_file )
 	{
 		// read the batch file and parse the command-line
 		G::BatchFile batch_file( config_file , std::nothrow ) ;
-		G::StringArray const args = batch_file.args() ;
-		if( args.size() != 0U )
+		if( !batch_file.args().empty() )
 		{
 			G::OptionMap option_map ;
 			G::Options options = Main::Options::spec( G::is_windows() ) ;
 			G::OptionParser parser( options , option_map ) ;
-			parser.parse( args , 1U ) ; // ignore errors
+			parser.parse( batch_file.args() , 1U ) ; // ignore errors
 			config = G::MapFile( option_map , G::Str::positive() ) ;
 		}
 	}
 	else
 	{
-		config = G::MapFile( config_file ) ;
+		config = G::MapFile( config_file , "config" ) ;
 	}
 
 	// normalise by expanding "--as-whatever" etc.
