@@ -1,27 +1,30 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
-//
-// filter.cpp
-//
+///
+/// \file filter.cpp
+///
 // A utility that can be installed as a "--filter" program to copy the message
 // envelope into all spool sub-directories for use by "--pop-by-name".
 //
-// If the envelope in the parent directory has been copied at least once then
-// it is removed and the program exits with a value of 100.
+// If the envelope in the parent directory is successfully copied to at least
+// once sub-directory then it is removed from the parent directory and the
+// program exits with a value of 100.
+//
+// Fails if there are no sub-directories to copy in to.
 //
 
 #include "gdef.h"
@@ -60,19 +63,28 @@ static void help( const std::string & prefix )
 
 struct Filter
 {
-	std::string m_envelope_name ;
-	G::Path m_envelope_path ; // "<spool-dir>/<envelope-name>[.new]"
-	bool m_envelope_deleted ;
-	int m_directory_count ;
-	std::set<std::string> m_failures ;
-	bool m_verbose ;
-	bool m_dryrun ;
-
-	Filter() : m_envelope_deleted(false) , m_directory_count(0) , m_verbose(false) , m_dryrun(false) {}
+public:
+	Filter() = default;
+	explicit Filter( bool verbose ) : m_verbose(verbose) {}
 	void process_content( const std::string & ) ;
 	void process_envelope() ;
-	void notify( bool ) ;
+	void throwFailures( bool ) ;
 	bool ok() const { return m_failures.empty() ; }
+	bool envelopeDeleted() const { return m_envelope_deleted ; }
+	void setEnvelope( const std::string & name , const G::Path & path )
+	{
+		m_envelope_name = name ;
+		m_envelope_path = path ;
+	}
+
+private:
+	std::string m_envelope_name ;
+	G::Path m_envelope_path ; // "<spool-dir>/<envelope-name>[.new]"
+	bool m_envelope_deleted{false} ;
+	int m_directory_count{0} ;
+	std::set<std::string> m_failures ;
+	bool m_verbose{false} ;
+	bool m_dryrun{false} ;
 } ;
 
 void Filter::process_envelope()
@@ -83,7 +95,7 @@ void Filter::process_envelope()
 	// which gets inherited by sub-directories and all message
 	// files
 	//
-	G::Process::Umask::set( G::Process::Umask::Mode::Tighter ) ; // 0177
+	G::Process::Umask::set( G::Process::Umask::Mode::Tighter ) ; // 0117
 
 	// copy the envelope into all sub-directories
 	//
@@ -98,7 +110,7 @@ void Filter::process_envelope()
 			G::Path subdir = iter.filePath() ;
 			copies++ ;
 			G::Path target = G::Path( subdir , m_envelope_name ) ;
-			bool copied = m_dryrun ? true : G::File::copy( m_envelope_path , target , G::File::NoThrow() ) ;
+			bool copied = m_dryrun ? true : G::File::copy( m_envelope_path , target , std::nothrow ) ;
 			if( m_verbose )
 				std::cout << (copied?"copied":"failed") << ": " << m_envelope_path << " " << target << "\n" ;
 			if( !copied )
@@ -115,7 +127,7 @@ void Filter::process_envelope()
 	//
 	if( copies > 0 && failures == 0 )
 	{
-		m_envelope_deleted = m_dryrun ? true : G::File::remove( m_envelope_path , G::File::NoThrow() ) ;
+		m_envelope_deleted = m_dryrun ? true : G::File::remove( m_envelope_path , std::nothrow ) ;
 	}
 }
 
@@ -154,7 +166,7 @@ void Filter::process_content( const std::string & content )
 	process_envelope() ;
 }
 
-void Filter::notify( bool one )
+void Filter::throwFailures( bool one )
 {
 	if( ! m_failures.empty() )
 	{
@@ -179,7 +191,7 @@ void Filter::notify( bool one )
 	}
 	if( one && m_directory_count == 0 ) // probably a permissioning problem
 	{
-		throw FilterError( "no sub-directories to copy into: check permissions" ) ;
+		throw FilterError( "no sub-directories to copy into" , G::is_windows() ? "" : "check permissions" ) ;
 	}
 }
 
@@ -189,26 +201,24 @@ static bool run_one( const std::string & content )
 	//
 	Filter filter ;
 	filter.process_content( content ) ;
-	filter.notify( true ) ;
-	return filter.m_envelope_deleted ;
+	filter.throwFailures( true ) ;
+	return filter.envelopeDeleted() ;
 }
 
 static bool run_all( const std::string & spool_dir , bool verbose )
 {
-	Filter filter ;
-	filter.m_verbose = verbose ;
+	Filter filter( verbose ) ;
 	G::Directory dir( spool_dir ) ;
 	G::DirectoryIterator iter( dir ) ;
 	while( iter.more() && !iter.error() )
 	{
-		if( !iter.isDir() && G::Str::headMatch(iter.fileName(),"emailrelay") && iter.filePath().extension().compare("envelope")==0 )
+		if( !iter.isDir() && G::Str::headMatch(iter.fileName(),"emailrelay") && iter.filePath().extension() == "envelope" )
 		{
-			filter.m_envelope_name = iter.fileName() ;
-			filter.m_envelope_path = iter.filePath() ;
+			filter.setEnvelope( iter.fileName() , iter.filePath() ) ;
 			filter.process_envelope() ;
 		}
 	}
-	filter.notify( false ) ;
+	filter.throwFailures( false ) ;
 	return filter.ok() ;
 }
 
@@ -271,4 +281,3 @@ int main( int argc , char * argv [] )
 	return 1 ;
 }
 
-/// \file filter.cpp
