@@ -68,7 +68,7 @@ namespace { std::string localedir() { return std::string() ; } }
 
 std::string Main::Run::versionNumber()
 {
-	return "2.2" ;
+	return "2.3" ;
 }
 
 Main::Run::Run( Main::Output & output , const G::Arg & arg , bool is_windows , bool has_gui ) :
@@ -83,6 +83,7 @@ Main::Run::Run( Main::Output & output , const G::Arg & arg , bool is_windows , b
 {
 	m_client_ptr.deletedSignal().connect( G::Slot::slot(*this,&Run::onClientDone) ) ;
 	m_client_ptr.eventSignal().connect( G::Slot::slot(*this,&Run::onClientEvent) ) ;
+	m_forward_request_signal.connect( G::Slot::slot(*this,&Run::onForwardRequest) ) ;
 
 	// initialise gettext() early iff "--localedir" is used
 	std::string ldir = localedir() ;
@@ -111,6 +112,7 @@ Main::Run::~Run()
 	if( m_smtp_server ) m_smtp_server->eventSignal().disconnect() ;
 	if( m_store ) m_store->messageStoreRescanSignal().disconnect() ;
 	if( m_monitor ) m_monitor->signal().disconnect() ;
+	m_forward_request_signal.disconnect() ;
 	m_client_ptr.deletedSignal().disconnect() ;
 	m_client_ptr.eventSignal().disconnect() ;
 }
@@ -287,9 +289,10 @@ void Main::Run::run()
 	m_monitor = std::make_unique<GNet::Monitor>() ;
 	m_monitor->signal().connect( G::Slot::slot(*this,&Run::onNetworkEvent) ) ;
 
-	// early check of the forward-to address
+	// early check that the forward-to address can be resolved
 	//
-	if( configuration().log() && !configuration().serverAddress().empty() && !configuration().forwardOnStartup() )
+	if( configuration().log() && !configuration().serverAddress().empty() && !configuration().forwardOnStartup() &&
+		!GNet::Address::isFamilyLocal( configuration().serverAddress() ) )
 	{
 		GNet::Location location( configuration().serverAddress() , resolverFamily() ) ;
 		std::string error = GNet::Resolver::resolve( location ) ;
@@ -321,8 +324,9 @@ void Main::Run::run()
 
 	// create message store singletons
 	//
-	m_store = std::make_unique<GSmtp::FileStore>( configuration().spoolDir() , false ,
+	m_store = std::make_unique<GSmtp::FileStore>( configuration().spoolDir() ,
 		configuration().maxSize() , configuration().eightBitTest() ) ;
+	m_filter_factory = std::make_unique<GSmtp::FilterFactoryFileStore>( *m_store ) ;
 	m_store->messageStoreRescanSignal().connect( G::Slot::slot(*this,&Run::onStoreRescanEvent) ) ;
 	if( do_pop )
 	{
@@ -359,9 +363,10 @@ void Main::Run::run()
 		m_smtp_server = std::make_unique<GSmtp::Server>(
 			m_es_rethrow ,
 			*m_store ,
+			*m_filter_factory ,
 			*m_client_secrets ,
 			*m_server_secrets ,
-			serverConfig() ,
+			smtpServerConfig() ,
 			configuration().immediate() ? configuration().serverAddress() : std::string() ,
 			clientConfig() ) ;
 
@@ -391,7 +396,10 @@ void Main::Run::run()
 			m_es_rethrow ,
 			configuration() ,
 			*m_store ,
+			*m_filter_factory ,
+			m_forward_request_signal ,
 			GNet::ServerPeerConfig(0U) ,
+			netServerConfig() ,
 			clientConfig() ,
 			*m_client_secrets ,
 			versionNumber() ) ;
@@ -474,31 +482,24 @@ void Main::Run::checkPort( bool check , const std::string & ip , unsigned int po
 	if( check )
 	{
 		const bool do_throw = true ;
-		try
+		if( ip.empty() )
 		{
-			if( ip.empty() )
+			if( GNet::Address::supports( GNet::Address::Family::ipv6 ) &&
+				GNet::StreamSocket::supports( GNet::Address::Family::ipv6 ) )
 			{
-				if( GNet::Address::supports( GNet::Address::Family::ipv6 ) &&
-					GNet::StreamSocket::supports( GNet::Address::Family::ipv6 ) )
-				{
-					GNet::Address address( GNet::Address::Family::ipv6 , port ) ;
-					GNet::Server::canBind( address , do_throw ) ;
-				}
-				if( GNet::Address::supports( GNet::Address::Family::ipv4 ) )
-				{
-					GNet::Address address( GNet::Address::Family::ipv4 , port ) ;
-					GNet::Server::canBind( address , do_throw ) ;
-				}
+				GNet::Address address( GNet::Address::Family::ipv6 , port ) ;
+				GNet::Server::canBind( address , do_throw ) ;
 			}
-			else if( GNet::Address::validStrings(ip,"0") )
+			if( GNet::Address::supports( GNet::Address::Family::ipv4 ) )
 			{
-				GNet::Address address( ip , port ) ;
+				GNet::Address address( GNet::Address::Family::ipv4 , port ) ;
 				GNet::Server::canBind( address , do_throw ) ;
 			}
 		}
-		catch( G::Exception & e )
+		else if( GNet::Address::validStrings(ip,"0") )
 		{
-			throw e.translated() ;
+			GNet::Address address = GNet::Address::parse( ip , port ) ;
+			GNet::Server::canBind( address , do_throw ) ;
 		}
 	}
 }
@@ -554,7 +555,14 @@ GSmtp::ServerProtocol::Config Main::Run::serverProtocolConfig() const
 			.set_allow_pipelining( configuration().smtpPipelining() ) ;
 }
 
-GSmtp::Server::Config Main::Run::serverConfig() const
+GNet::ServerConfig Main::Run::netServerConfig() const
+{
+	bool open = configuration().user().empty() || configuration().user() == "root" ;
+	return GNet::ServerConfig()
+		.set_uds_open_permissions( open ) ;
+}
+
+GSmtp::Server::Config Main::Run::smtpServerConfig() const
 {
 	return
 		GSmtp::Server::Config()
@@ -568,6 +576,7 @@ GSmtp::Server::Config Main::Run::serverConfig() const
 			.set_verifier_address( configuration().verifier().str() )
 			.set_verifier_timeout( configuration().filterTimeout() )
 			.set_server_peer_config( GNet::ServerPeerConfig(configuration().idleTimeout()) )
+			.set_server_config( netServerConfig() )
 			.set_protocol_config( serverProtocolConfig() )
 			.set_sasl_server_config( configuration().smtpSaslServerConfig() )
 			.set_dnsbl_config( configuration().dnsbl() ) ;
@@ -583,6 +592,7 @@ GPop::Server::Config Main::Run::popConfig() const
 			.set_server_peer_config(
 				GNet::ServerPeerConfig()
 					.set_idle_timeout( configuration().idleTimeout()) )
+			.set_server_config( netServerConfig() )
 			.set_sasl_server_config( configuration().popSaslServerConfig() ) ;
 }
 
@@ -617,7 +627,7 @@ GNet::Address Main::Run::asAddress( const std::string & s )
 	// (port number is optional)
 	return s.empty() ?
 		GNet::Address::defaultAddress() :
-		( GNet::Address::validString(s) ? GNet::Address(s) : GNet::Address(s,0U) ) ;
+		( GNet::Address::validString(s,GNet::Address::NotLocal()) ? GNet::Address::parse(s,GNet::Address::NotLocal()) : GNet::Address::parse(s,0U) ) ;
 }
 
 void Main::Run::onPollTimeout()
@@ -627,6 +637,11 @@ void Main::Run::onPollTimeout()
 	requestForwarding( "poll" ) ;
 }
 
+void Main::Run::onForwardRequest( const std::string & reason )
+{
+	requestForwarding( reason ) ;
+}
+
 void Main::Run::requestForwarding( const std::string & reason )
 {
 	G_ASSERT( m_forwarding_timer != nullptr ) ;
@@ -682,6 +697,7 @@ std::string Main::Run::startForwarding()
 			G_ASSERT( m_client_secrets != nullptr ) ;
 			m_client_ptr.reset( std::make_unique<GSmtp::Client>(
 				GNet::ExceptionSink(m_client_ptr,nullptr) ,
+				*m_filter_factory ,
 				GNet::Location(configuration().serverAddress(),resolverFamily()) ,
 				*m_client_secrets ,
 				clientConfig() ) ) ;
@@ -796,10 +812,11 @@ int Main::Run::resolverFamily() const
 {
 	// choose an address family for the DNS lookup based on the "--client-interface" address
 	std::string client_bind_address = configuration().clientBindAddress() ;
-	return
-		client_bind_address.empty() ?
-			AF_UNSPEC :
-			asAddress(client_bind_address).domain() ;
+	if( client_bind_address.empty() )
+		return AF_UNSPEC ;
+
+	GNet::Address address = asAddress( client_bind_address ) ;
+	return ( address.af() == AF_INET || address.af() == AF_INET6 ) ? address.af() : AF_UNSPEC ;
 }
 
 void Main::Run::checkScripts() const
@@ -855,8 +872,9 @@ G::Path Main::Run::appDir() const
 }
 
 std::unique_ptr<GSmtp::AdminServer> Main::Run::newAdminServer( GNet::ExceptionSink es ,
-	const Configuration & cfg , GSmtp::MessageStore & store ,
-	const GNet::ServerPeerConfig & server_peer_config ,
+	const Configuration & cfg , GSmtp::MessageStore & store , GSmtp::FilterFactory & ff ,
+	G::Slot::Signal<const std::string&> & forward_request_signal ,
+	const GNet::ServerPeerConfig & server_peer_config , const GNet::ServerConfig & net_server_config ,
 	const GSmtp::Client::Config & client_config , const GAuth::Secrets & client_secrets ,
 	const std::string & version_number )
 {
@@ -873,7 +891,10 @@ std::unique_ptr<GSmtp::AdminServer> Main::Run::newAdminServer( GNet::ExceptionSi
 	return std::make_unique<GSmtp::AdminServer>(
 			es ,
 			store ,
+			ff ,
+			forward_request_signal ,
 			server_peer_config ,
+			net_server_config ,
 			client_config ,
 			client_secrets ,
 			cfg.listeningAddresses("admin") ,
