@@ -1,16 +1,16 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
@@ -18,8 +18,8 @@
 /// \file winform.h
 ///
 
-#ifndef WIN_FORM_H
-#define WIN_FORM_H
+#ifndef G_MAIN_WIN_FORM_H
+#define G_MAIN_WIN_FORM_H
 
 #include "gdef.h"
 #include "gstrings.h"
@@ -38,7 +38,7 @@ namespace Main
 	class WinApp ;
 }
 
-/// \class Main::WinForm
+//| \class Main::WinForm
 /// A class for the main user interface that is-a property-sheet stack
 /// containing property-page dialog boxes. In practice each dialog box
 /// is made up of a COMMCTL List View control (see GGui::ListView).
@@ -76,9 +76,14 @@ private: // overrides
 	virtual void onInit( HWND , int ) override ; // Override from StackPageCallback.
 	virtual bool onApply() override ; // Override from StackPageCallback.
 
+public:
+	~WinForm() = default ;
+	WinForm( const WinForm & ) = delete ;
+	WinForm( WinForm && ) = delete ;
+	void operator=( const WinForm & ) = delete ;
+	void operator=( WinForm && ) = delete ;
+
 private:
-	WinForm( const WinForm & ) g__eq_delete ;
-	void operator=( const WinForm & ) g__eq_delete ;
 	static void add( G::StringArray & s , const std::string & key , const std::string & value ) ;
 	static void add( G::StringArray & list , std::string s ) ;
 	static G::StringArray split( const std::string & s ) ;
@@ -91,14 +96,14 @@ private:
 	static std::string timestamp() ;
 
 private:
-	typedef std::map<std::string,std::pair<std::string,std::string> > StatusMap ;
+	using StatusMap = std::map<std::string,std::pair<std::string,std::string>> ;
 	HWND m_hnotify ;
 	bool m_allow_apply ;
 	bool m_closed ;
-	unique_ptr<GGui::ListView> m_cfg_view ;
-	unique_ptr<GGui::ListView> m_status_view ;
-	unique_ptr<GGui::ListView> m_version_view ;
-	unique_ptr<GGui::ListView> m_licence_view ;
+	std::unique_ptr<GGui::ListView> m_cfg_view ;
+	std::unique_ptr<GGui::ListView> m_status_view ;
+	std::unique_ptr<GGui::ListView> m_version_view ;
+	std::unique_ptr<GGui::ListView> m_licence_view ;
 	Configuration m_cfg ;
 	StatusMap m_status_map ;
 } ;
