@@ -1,22 +1,22 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
-//
-// winmain.cpp
-//
+///
+/// \file winmain.cpp
+///
 
 #include "gdef.h"
 #include "garg.h"
@@ -33,13 +33,15 @@ int WINAPI WinMain( HINSTANCE hinstance , HINSTANCE previous , LPSTR command_lin
 {
 	try
 	{
-		::setlocale( LC_ALL , "" ) ; // set the locale from the environment
+		// set the C locale from the environment
+		// (has no effect on the msvc run-time)
+		::setlocale( LC_ALL , "" ) ;
 
 		G::Arg arg ;
 		arg.parse( hinstance , command_line ) ;
 
 		Main::WinApp app( hinstance , previous , "E-MailRelay" ) ;
-		Main::Run run( app , arg , Main::Options::spec(true) , true ) ;
+		Main::Run run( app , arg , true , true ) ;
 		try
 		{
 			run.configure() ;
@@ -69,4 +71,3 @@ int WINAPI WinMain( HINSTANCE hinstance , HINSTANCE previous , LPSTR command_lin
 	return 1 ;
 }
 
-/// \file winmain.cpp
