@@ -1,16 +1,16 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
@@ -18,8 +18,8 @@
 /// \file gappinst.h
 ///
 
-#ifndef G_APPINST_H
-#define G_APPINST_H
+#ifndef G_GUI_APPINST_H
+#define G_GUI_APPINST_H
 
 #include "gdef.h"
 
@@ -28,7 +28,7 @@ namespace GGui
 	class ApplicationInstance ;
 }
 
-/// \class GGui::ApplicationInstance
+//| \class GGui::ApplicationInstance
 /// A class for storing the application's instance handle, as
 /// obtained from WinMain().
 ///
