@@ -1,16 +1,16 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
@@ -18,8 +18,8 @@
 /// \file gcracker.h
 ///
 
-#ifndef G_CRACKER_H
-#define G_CRACKER_H
+#ifndef G_GUI_CRACKER_H
+#define G_GUI_CRACKER_H
 
 #include "gdef.h"
 #include "gwinbase.h"
@@ -32,7 +32,7 @@ namespace GGui
 	class Cracker ;
 }
 
-/// \class GGui::Cracker
+//| \class GGui::Cracker
 /// The Cracker class encapsulates a typical window procedure by
 /// 'cracking' Windows messages into virtual functions.
 ///
@@ -90,7 +90,7 @@ protected:
 		///< Overridable. Called when the window receives a
 		///< WM_SYSCOLORCHANGE message.
 
-	g__enum(SysCommand) { scMaximise , scMinimise , scClose , scSize /*etc*/ } ; g__enum_end(SysCommand)
+	enum class SysCommand { scMaximise , scMinimise , scClose , scSize /*etc*/ } ;
 	virtual bool onSysCommand( SysCommand sys_command ) ;
 		///< Overridable. Called when the window receives a
 		///< WM_SYSCOMMAND message. Returns true if processed.
@@ -137,7 +137,7 @@ protected:
 		///< WM_DROPFILES message. Returns false if the file list
 		///< is ignored. See also: DragAcceptFiles().
 
-	g__enum(SizeType) { maximised , minimised , restored } ; g__enum_end(SizeType)
+	enum class SizeType { maximised , minimised , restored } ;
 	virtual void onSize( SizeType type , unsigned int dx , unsigned int dy ) ;
 		///< Overridable. Called on receipt of a WM_SIZE message.
 
@@ -226,8 +226,8 @@ protected:
 		bool right_button_down ) ;
 			///< Overridable. Called on receipt of a mouse-move message.
 
-	g__enum(MouseButton) { Left , Middle , Right } ; g__enum_end(MouseButton)
-	g__enum(MouseButtonDirection) { Up , Down } ; g__enum_end(MouseButtonDirection)
+	enum class MouseButton { Left , Middle , Right } ;
+	enum class MouseButtonDirection { Up , Down } ;
 
 	virtual void onMouseButton( MouseButton , MouseButtonDirection ,
 		int x , int y , bool shift_key_down , bool control_key_down ) ;
@@ -289,10 +289,14 @@ protected:
 		///< still empty).
 		/// \see GGui::Pump
 
+public:
+	Cracker( const Cracker & ) = delete ;
+	Cracker( Cracker && ) = delete ;
+	void operator=( const Cracker & ) = delete ;
+	void operator=( Cracker && ) = delete ;
+
 private:
-	Cracker( const Cracker &other ) g__eq_delete ;
-	void operator=( const Cracker & other ) g__eq_delete ;
-	typedef void (Cracker::*Fn)(int,int,bool,bool) ;
+	using Fn = void (Cracker::*)(int,int,bool,bool) ;
 	LRESULT doMouseButton( Fn fn , MouseButton , MouseButtonDirection , unsigned int , WPARAM , LPARAM ) ;
 	LRESULT onControlColour_( WPARAM hDC , LPARAM hWndControl , WORD type ) ;
 	static HWND hwnd_from( WPARAM ) ;
