@@ -1,16 +1,16 @@
 //
-// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
-//
+// Copyright (C) 2001-2021 Graeme Walker <graeme_walker@users.sourceforge.net>
+// 
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
@@ -18,8 +18,8 @@
 /// \file gwinbase.h
 ///
 
-#ifndef G_WINBASE_H
-#define G_WINBASE_H
+#ifndef G_GUI_WINBASE_H
+#define G_GUI_WINBASE_H
 
 #include "gdef.h"
 #include "gsize.h"
@@ -29,7 +29,7 @@ namespace GGui
 	class WindowBase ;
 }
 
-/// \class GGui::WindowBase
+//| \class GGui::WindowBase
 /// A low-level window class that encapsulates a window handle
 /// and provides methods to retrieve basic window attributes.
 /// Knows nothing about window messages.
@@ -65,9 +65,11 @@ protected:
 	void setHandle( HWND hwnd ) ;
 		///< Sets the window handle.
 
-private:
-	WindowBase( const WindowBase & other ) g__eq_delete ;
-	void operator=( const WindowBase &other ) g__eq_delete ;
+public:
+	WindowBase( const WindowBase & ) = delete ;
+	WindowBase( WindowBase && ) = delete ;
+	void operator=( const WindowBase & ) = delete ;
+	void operator=( WindowBase && ) = delete ;
 
 private:
 	HWND m_hwnd ;
